@@ -27,10 +27,20 @@ fi
 
 export PATH=.:$PATH
 source regexf_unittest.sh
-#echo "Call: `which regexf`"
 
-#assertContains "./regexf -h","Compare patterns"
-assertEquals "./regexf aa/bb/cc","./regexf.ini:re.match<aa/bb/cc> fail"
+configFile=/usr/local/bin/regexf.ini
+assertEquals "regexf aa/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
+assertEquals "regexf aa/bb/cc vac/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
+assertContains "regexf vac/bb/cc -v" " match"
+assertContains "regexf -i -f $configFile" "regexf_version"
 
-#assertEquals "./regexf sys/tg_test/1",""
-#assertEquals "./regexf sys/tg_test/1 -v","./regexf.ini:re.match\(^sys/\w+/\w+$,sys/tg_test/1\) pass"
+test_file=/usr/local/bin/regexf_test.ini
+
+#test_file
+#echo "[tango]
+#patterns=
+#    ^([amk])/(\w+)/(\w+)$" > $test_file
+
+assertEquals "regexf -f $test_file aa/bb/cc" "$test_file:re.match<aa/bb/cc> no_match"
+assertEquals "regexf -f $test_file m/bb/cc" ""
+#rm $test_file
